# Copyright (c) 2023 by Ivanti. All rights reserved

import argparse
import os
import sys

import oci
import yaml

# Escape codes for text styling
RESET = "\033[0m"
RED = "\033[91m"
GREEN = "\033[92m"
CYAN = "\033[96m"
BOLD = "\033[1m"
UNDERLINE = "\033[4m"


# Function to read the oci config file.
def read_oci_config(custom_location=None):
    # Use the provided location, or fall back to the default
    try:
        if custom_location is not None:
            return oci.config.from_file(file_location=custom_location)
        else:
            return oci.config.from_file()
    except:
        return None


def update_ext_public_ip_metdata(
     vnic_id, instance_id,lb_id,config_file=None
):
    try:
        config = read_oci_config(config_file)
        if config is None:
            print(
                f"\n{RED}{BOLD}{UNDERLINE}Udpate Failed. Please refer to the below message for more details,{RESET}"
            )
            print(f"\n{CYAN}Invalid oci configuration {RESET}\n")
            exit(0)

        compute_client = oci.core.ComputeClient(config)
        virtual_network_client = oci.core.VirtualNetworkClient(config)
        load_balancer_client = oci.load_balancer.LoadBalancerClient(config)
        vnic = virtual_network_client.get_vnic(vnic_id).data

        if lb_id is not None :
            lb_detail = load_balancer_client.get_load_balancer(lb_id).data
            public_ip = lb_detail.ip_addresses[0]

        else:
        # Check if the VNIC has a public IP assigned
            if vnic.public_ip is not None:
                public_ip = vnic.public_ip
            else :
                print("No public IP address assigned to the VNIC.")
        print(
            f"Processing: Updating public IP " + public_ip + f".....{RESET}", end=" "
        )

        # Create custom metadata for the VNIC
        custom_metadata = {
            "ext_public_ip": public_ip  # Add the public IP to the custom metadata
        }

        # Get the current instance details
        instance = compute_client.get_instance(instance_id).data

        # Merge the new metadata with the existing metadata (if any)
        updated_metadata = instance.metadata.copy()
        updated_metadata.update(custom_metadata)

        # Update the instance with the new metadata
        updated_instance = compute_client.update_instance(
            instance_id,
            oci.core.models.UpdateInstanceDetails(metadata=updated_metadata),
        ).data
        print(f"{GREEN}Success.{RESET}\n")
  

    except oci.exceptions.ServiceError as e:
            print(f"{RED}Failed")
            print(
                f"\n{RED}{BOLD}{UNDERLINE}Udpate Failed. Please refer to the below message for more details,{RESET}"
            )
            print(f"\n{CYAN}" + e.message + f"{RESET}\n")



if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="Read OCI Config file.")
    parser.add_argument("-c", "--config", help="Custom config location", default=None)
    parser.add_argument("-v", "--vnic", help="VNIC Id", default=None)
    parser.add_argument("-i", "--instance", help="Instance Id", default=None)
    parser.add_argument("-l", "--lb", help="Loadbalancer Id", default=None)
    args = parser.parse_args()
    update_ext_public_ip_metdata(args.vnic,args.instance,args.lb,args.config)
